set_comments_before

Function set_comments_before 

pub fn set_comments_before(decor: &mut Decor, lines: &[String])
Replace the comment lines in a decor’s prefix, keeping the blank lines before them and the indentation after them. No lines removes the comment and leaves the whitespace.