pub fn set_trailing_comments(doc: &mut DocumentMut, lines: &[String])Expand description
Replace the comment lines after the last item, keeping the blank lines before them.
pub fn set_trailing_comments(doc: &mut DocumentMut, lines: &[String])Replace the comment lines after the last item, keeping the blank lines before them.